@@ -44,9 +44,9 @@ char *passwd = "";
 void 
 cqiserver_welcome(void)
 {
-  printf("** CQPserver v" VERSION "\n");
-  printf("** implementing version %d.%d of the CQi\n", CQI_MAJOR_VERSION, CQI_MINOR_VERSION);
-  printf("\n");
+ Rprintf("** CQPserver v" VERSION "\n");
+ Rprintf("** implementing version %d.%d of the CQi\n", CQI_MAJOR_VERSION, CQI_MINOR_VERSION);
+ Rprintf("\n");
 }
 
 
@@ -64,8 +64,8 @@ cqiserver_welcome(void)
 void 
 cqiserver_unknown_command_error(int cmd)
 {
-  fprintf(stderr, "CQPserver: unknown CQi command 0x%04X.\n", cmd);
-  exit(1);
+ Rprintf( "CQPserver: unknown CQi command 0x%04X.\n", cmd);
+  rcqp_receive_error(1);
 }
 
 /**
@@ -76,8 +76,8 @@ cqiserver_unknown_command_error(int cmd)
 void 
 cqiserver_wrong_command_error(int cmd)
 {
-  fprintf(stderr, "CQPserver: command 0x%04X not allowed in this context.\n", cmd);
-  exit(1);
+ Rprintf( "CQPserver: command 0x%04X not allowed in this context.\n", cmd);
+  rcqp_receive_error(1);
 }
 
 /**
@@ -92,9 +92,9 @@ cqiserver_wrong_command_error(int cmd)
 void
 cqiserver_internal_error(char *function, char *reason)
 {
-  fprintf(stderr, "CQPserver: internal error in %s()\n", function);
-  fprintf(stderr, "CQPserver: ''%s''\n", reason);
-  exit(1);
+ Rprintf( "CQPserver: internal error in %s()\n", function);
+ Rprintf( "CQPserver: ''%s''\n", reason);
+  rcqp_receive_error(1);
 }
 
 
@@ -147,14 +147,14 @@ send_cl_error(void)
     cmd = CQI_CL_ERROR_INTERNAL;
     break;
   case CDA_OK:
-    fprintf(stderr, "CQPserver: send_cl_error() called with cderrno == CDA_OK\n");
-    exit(1);
+   Rprintf( "CQPserver: send_cl_error() called with cderrno == CDA_OK\n");
+    rcqp_receive_error(1);
   default:
-    fprintf(stderr, "CQPserver: send_cl_error() unknown value in cderrno\n");
-    exit(1);
+   Rprintf( "CQPserver: send_cl_error() unknown value in cderrno\n");
+    rcqp_receive_error(1);
   }
   if (server_debug)
-    fprintf(stderr, "CQi: CL error, returning 0x%04X\n", cmd);
+   Rprintf( "CQi: CL error, returning 0x%04X\n", cmd);
   cqi_command(cmd);
   return;
 }
@@ -173,7 +173,7 @@ do_cqi_corpus_list_corpora(void)
   int n = 0;
   
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CORPUS_LIST_CORPORA()\n");
+   Rprintf( "CQi: CQI_CORPUS_LIST_CORPORA()\n");
   /* ugly, but it's easiest ... first count corpora, then return names one by one */
   for (cl = FirstCorpusFromList(); cl != NULL; cl = NextCorpusFromList(cl)) {
     if (cl->type == SYSTEM)
@@ -195,7 +195,7 @@ do_cqi_corpus_charset(void)
 
   c = cqi_read_string();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CORPUS_CHARSET('%s')\n", c);
+   Rprintf( "CQi: CQI_CORPUS_CHARSET('%s')\n", c);
   /* this is a dummy until we've implemented the registry extensions */
   cqi_data_string("latin1");
   free(c);
@@ -208,7 +208,7 @@ do_cqi_corpus_properties(void)
 
   c = cqi_read_string();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CORPUS_PROPERTIES('%s')\n", c);
+   Rprintf( "CQi: CQI_CORPUS_PROPERTIES('%s')\n", c);
   /* this is a dummy until we've implemented the registry extensions */
   cqi_data_string_list(NULL, 0);
   free(c);
@@ -256,7 +256,7 @@ do_cqi_corpus_attributes(int type)
       cqi_general_error("INTERNAL ERROR: do_cqi_corpus_attributes(): unknown attribute type");
       return;
     }
-    fprintf(stderr, "CQi: CQI_CORPUS_%s_ATTRIBUTES('%s')\n", typename, c);
+   Rprintf( "CQi: CQI_CORPUS_%s_ATTRIBUTES('%s')\n", typename, c);
   }
   cl = findcorpus(c, SYSTEM, 0);
   if (cl == NULL || !access_corpus(cl)) {
@@ -276,7 +276,7 @@ do_cqi_corpus_full_name(void)
 
   c = cqi_read_string();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CORPUS_FULL_NAME('%s')\n", c);
+   Rprintf( "CQi: CQI_CORPUS_FULL_NAME('%s')\n", c);
   cl = findcorpus(c, SYSTEM, 0);
   if (cl == NULL || !access_corpus(cl)) {
     cqi_command(CQI_CQP_ERROR_NO_SUCH_CORPUS);
@@ -294,7 +294,7 @@ do_cqi_corpus_structural_attribute_has_values(void) {
           
   a = cqi_read_string();        /* need to try all possible attribute types */
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CORPUS_STRUCTURAL_ATTRIBUTE_HAS_VALUES('%s')\n", a);
+   Rprintf( "CQi: CQI_CORPUS_STRUCTURAL_ATTRIBUTE_HAS_VALUES('%s')\n", a);
   attribute = cqi_lookup_attribute(a, ATT_STRUC);
   if (attribute != NULL) {
     cqi_data_bool(cl_struc_values(attribute));
@@ -314,7 +314,7 @@ do_cqi_cl_attribute_size(void)
           
   a = cqi_read_string();        /* need to try all possible attribute types */
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CL_ATTRIBUTE_SIZE('%s')\n", a);
+   Rprintf( "CQi: CQI_CL_ATTRIBUTE_SIZE('%s')\n", a);
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute != NULL) {
     size = cl_max_cpos(attribute);
@@ -366,7 +366,7 @@ do_cqi_cl_lexicon_size(void)
           
   a = cqi_read_string();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CL_LEXICON_SIZE('%s')\n", a);
+   Rprintf( "CQi: CQI_CL_LEXICON_SIZE('%s')\n", a);
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute != NULL) {
     size = cl_max_id(attribute);
@@ -387,7 +387,7 @@ void
 do_cqi_cl_drop_attribute(void)
 {
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CL_DROP_ATTRIBUTE()  --  not implemented\n");
+   Rprintf( "CQi: CQI_CL_DROP_ATTRIBUTE()  --  not implemented\n");
  cqi_general_error("CQI_CL_DROP_ATTRIBUTE not implemented."); 
 }
 
@@ -404,10 +404,10 @@ do_cqi_cl_str2id(void)
   a = cqi_read_string();
   len = cqi_read_string_list(&strlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_STR2ID('%s', [", a);
+   Rprintf( "CQi: CQI_CL_STR2ID('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "'%s' ", strlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "'%s' ", strlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute == NULL) {
@@ -442,10 +442,10 @@ do_cqi_cl_id2str(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&idlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_ID2STR('%s', [", a);
+   Rprintf( "CQi: CQI_CL_ID2STR('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", idlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", idlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute == NULL) {
@@ -478,10 +478,10 @@ do_cqi_cl_id2freq(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&idlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_ID2FREQ('%s', [", a);
+   Rprintf( "CQi: CQI_CL_ID2FREQ('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", idlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", idlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute == NULL) {
@@ -516,10 +516,10 @@ do_cqi_cl_cpos2str(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&cposlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_CPOS2STR('%s', [", a);
+   Rprintf( "CQi: CQI_CL_CPOS2STR('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", cposlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", cposlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute == NULL) {
@@ -552,10 +552,10 @@ do_cqi_cl_cpos2id(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&cposlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_CPOS2ID('%s', [", a);
+   Rprintf( "CQi: CQI_CL_CPOS2ID('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", cposlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", cposlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute == NULL) {
@@ -590,10 +590,10 @@ do_cqi_cl_cpos2struc(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&cposlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_CPOS2STRUC('%s', [", a);
+   Rprintf( "CQi: CQI_CL_CPOS2STRUC('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", cposlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", cposlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_STRUC);
   if (attribute == NULL) {
@@ -631,10 +631,10 @@ do_cqi_cl_cpos2lbound(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&cposlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_CPOS2LBOUND('%s', [", a);
+   Rprintf( "CQi: CQI_CL_CPOS2LBOUND('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", cposlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", cposlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_STRUC);
   if (attribute == NULL) {
@@ -674,10 +674,10 @@ do_cqi_cl_cpos2rbound(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&cposlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_CPOS2RBOUND('%s', [", a);
+   Rprintf( "CQi: CQI_CL_CPOS2RBOUND('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", cposlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", cposlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_STRUC);
   if (attribute == NULL) {
@@ -717,10 +717,10 @@ do_cqi_cl_cpos2alg(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&cposlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_CPOS2ALG('%s', [", a);
+   Rprintf( "CQi: CQI_CL_CPOS2ALG('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", cposlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", cposlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_ALIGN);
   if (attribute == NULL) {
@@ -755,10 +755,10 @@ do_cqi_cl_struc2str(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&struclist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_STRUC2STR('%s', [", a);
+   Rprintf( "CQi: CQI_CL_STRUC2STR('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", struclist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", struclist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_STRUC);
   if (attribute == NULL) {
@@ -791,7 +791,7 @@ do_cqi_cl_id2cpos(void)
   a = cqi_read_string();
   id = cqi_read_int();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CL_ID2CPOS('%s', %d)\n", a, id);
+   Rprintf( "CQi: CQI_CL_ID2CPOS('%s', %d)\n", a, id);
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute == NULL) {
     cqi_command(cqi_errno);
@@ -819,10 +819,10 @@ do_cqi_cl_idlist2cpos(void)
   a = cqi_read_string();
   len = cqi_read_int_list(&idlist);
   if (server_debug) {
-    fprintf(stderr, "CQi: CQI_CL_IDLIST2CPOS('%s', [", a);
+   Rprintf( "CQi: CQI_CL_IDLIST2CPOS('%s', [", a);
     for (i=0; i<len; i++)
-      fprintf(stderr, "%d ", idlist[i]);
-    fprintf(stderr, "])\n");
+     Rprintf( "%d ", idlist[i]);
+   Rprintf( "])\n");
   }
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute == NULL) {
@@ -854,7 +854,7 @@ do_cqi_cl_regex2id(void)
   a = cqi_read_string();
   regex = cqi_read_string();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CL_REGEX2ID('%s', '%s')\n", a, regex);
+   Rprintf( "CQi: CQI_CL_REGEX2ID('%s', '%s')\n", a, regex);
   attribute = cqi_lookup_attribute(a, ATT_POS);
   if (attribute == NULL) {
     cqi_command(cqi_errno);
@@ -886,7 +886,7 @@ do_cqi_cl_struc2cpos(void)
   a = cqi_read_string();
   struc = cqi_read_int();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CL_STRUC2CPOS('%s', %d)\n", a, struc);
+   Rprintf( "CQi: CQI_CL_STRUC2CPOS('%s', %d)\n", a, struc);
   attribute = cqi_lookup_attribute(a, ATT_STRUC);
   if (attribute == NULL) {
     cqi_command(cqi_errno);
@@ -910,7 +910,7 @@ do_cqi_cl_alg2cpos(void)
   a = cqi_read_string();
   alg = cqi_read_int();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CL_ALG2CPOS('%s', %d)\n", a, alg);
+   Rprintf( "CQi: CQI_CL_ALG2CPOS('%s', %d)\n", a, alg);
   attribute = cqi_lookup_attribute(a, ATT_ALIGN);
   if (attribute == NULL) {
     cqi_command(cqi_errno);
@@ -933,7 +933,7 @@ do_cqi_cqp_list_subcorpora(void)
   
   corpus = cqi_read_string();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CQP_LIST_SUBCORPORA(%s)\n", corpus);
+   Rprintf( "CQi: CQI_CQP_LIST_SUBCORPORA(%s)\n", corpus);
   mother = cqi_find_corpus(corpus);
   if (!check_corpus_name(corpus) || mother == NULL) 
     cqi_command(cqi_errno);
@@ -988,7 +988,7 @@ do_cqi_cqp_query(void)
   child = cqi_read_string();
   query = cqi_read_string();
   if (server_debug) 
-    fprintf(stderr, "CQi: CQI_CQP_QUERY('%s', '%s', '%s')\n", mother, child, query);
+   Rprintf( "CQi: CQI_CQP_QUERY('%s', '%s', '%s')\n", mother, child, query);
   if (!split_subcorpus_spec(mother, &c, &sc)) {
     cqi_command(cqi_errno);
   }
@@ -1003,7 +1003,7 @@ do_cqi_cqp_query(void)
     else {
       query_lock = floor(1e9 * cl_runif()) + 1; /* activate query lock mode with random key */
 
-      printf("CQPSERVER: query_lock = %d\n", query_lock);
+     Rprintf("CQPSERVER: query_lock = %d\n", query_lock);
       if (query_has_semicolon(query))
         sprintf(cqp_query, "%s = %s", child, query);
       else
@@ -1020,9 +1020,9 @@ do_cqi_cqp_query(void)
           cqi_command(CQI_CQP_ERROR_GENERAL);
         else {
           if (server_log) {
-            printf("'%s' ran the following query on %s\n", user, mother);
-            printf("\t%s\n", cqp_query);
-            printf("and got %d matches.\n", childcl->size);
+           Rprintf("'%s' ran the following query on %s\n", user, mother);
+           Rprintf("\t%s\n", cqp_query);
+           Rprintf("and got %d matches.\n", childcl->size);
           }
           cqi_command(CQI_STATUS_OK);
 
@@ -1046,7 +1046,7 @@ do_cqi_cqp_subcorpus_size(void)
 
   subcorpus = cqi_read_string();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CQP_SUBCORPUS_SIZE('%s')\n", subcorpus);
+   Rprintf( "CQi: CQI_CQP_SUBCORPUS_SIZE('%s')\n", subcorpus);
   cl = cqi_find_corpus(subcorpus);
   if (cl == NULL) 
     cqi_command(cqi_errno);
@@ -1097,7 +1097,7 @@ do_cqi_cqp_subcorpus_has_field(void)
     field_ok = 0;
   }
   if (server_debug) 
-    fprintf(stderr, "CQi: CQI_CQP_SUBCORPUS_HAS_FIELD('%s', %s)\n", 
+   Rprintf( "CQi: CQI_CQP_SUBCORPUS_HAS_FIELD('%s', %s)\n", 
             subcorpus, fieldname);
 
   cl = cqi_find_corpus(subcorpus);
@@ -1174,7 +1174,7 @@ do_cqi_cqp_dump_subcorpus(void)
     field_ok = 0;
   }
   if (server_debug) 
-    fprintf(stderr, "CQi: CQI_CQP_DUMP_SUBCORPUS('%s', %s, %d, %d)\n", 
+   Rprintf( "CQi: CQI_CQP_DUMP_SUBCORPUS('%s', %s, %d, %d)\n", 
             subcorpus, fieldname, first, last);
 
   cl = cqi_find_corpus(subcorpus);
@@ -1229,7 +1229,7 @@ do_cqi_cqp_drop_subcorpus(void)
 
   subcorpus = cqi_read_string();
   if (server_debug)
-    fprintf(stderr, "CQi: CQI_CQP_DROP_SUBCORPUS('%s')\n", subcorpus);
+   Rprintf( "CQi: CQI_CQP_DROP_SUBCORPUS('%s')\n", subcorpus);
 
   /* make sure it is a subcorpus, not a root corpus */
   if (!split_subcorpus_spec(subcorpus, &c, &sc))
@@ -1282,7 +1282,7 @@ do_cqi_cqp_fdist_1(void)
     fieldtype = field_name_to_type(fieldname);
   }
   if (server_debug) 
-    fprintf(stderr, "CQi: CQI_CQP_FDIST_1('%s', %d, %s, %s)\n", 
+   Rprintf( "CQi: CQI_CQP_FDIST_1('%s', %d, %s, %s)\n", 
             subcorpus, cutoff, fieldname, att);
   
   cl = cqi_find_corpus(subcorpus);
@@ -1355,7 +1355,7 @@ do_cqi_cqp_fdist_2(void)
     fieldtype2 = field_name_to_type(fieldname2);
   }
   if (server_debug) 
-    fprintf(stderr, "CQi: CQI_CQP_FDIST_2('%s', %d, %s, %s, %s, %s)\n", 
+   Rprintf( "CQi: CQI_CQP_FDIST_2('%s', %d, %s, %s, %s, %s)\n", 
             subcorpus, cutoff, fieldname1, att1, fieldname2, att2);
   
   cl = cqi_find_corpus(subcorpus);
@@ -1419,21 +1419,21 @@ interpreter(void)
         cqiserver_wrong_command_error(cmd);
       case CQI_CTRL_BYE:
         if (server_debug) 
-          fprintf(stderr, "CQi: CQI_CTRL_BYE()\n");
+         Rprintf( "CQi: CQI_CTRL_BYE()\n");
         cqi_command(CQI_STATUS_BYE_OK);
         return;                 /* exit CQi command interpreter */
       case CQI_CTRL_USER_ABORT:
         if (server_debug)
-          fprintf(stderr, "CQi: CQI_CTRL_ABORT signal ... ignored\n");
+         Rprintf( "CQi: CQI_CTRL_ABORT signal ... ignored\n");
         break;
       case CQI_CTRL_PING:
         if (server_debug)
-          fprintf(stderr, "CQi: CQI_CTRL_PING()\n");
+         Rprintf( "CQi: CQI_CTRL_PING()\n");
         cqi_command(CQI_STATUS_PING_OK);
         break;
       case CQI_CTRL_LAST_GENERAL_ERROR:
         if (server_debug)
-          fprintf(stderr, "CQi: CQI_CTRL_LAST_GENERAL_ERROR() => '%s'", cqi_error_string);
+         Rprintf( "CQi: CQI_CTRL_LAST_GENERAL_ERROR() => '%s'", cqi_error_string);
         cqi_data_string(cqi_error_string);
         break;
       default:
@@ -1446,22 +1446,22 @@ interpreter(void)
       switch (cmd) {
       case CQI_ASK_FEATURE_CQI_1_0:
         if (server_debug)
-          fprintf(stderr, "CQi: CQI_ASK_FEATURE_CQI_1_0 ... CQi v1.0 ok\n");
+         Rprintf( "CQi: CQI_ASK_FEATURE_CQI_1_0 ... CQi v1.0 ok\n");
         cqi_data_bool(CQI_CONST_YES);
         break;
       case CQI_ASK_FEATURE_CL_2_3:
         if (server_debug)
-          fprintf(stderr, "CQi: CQI_ASK_FEATURE_CL_2_3 ... CL v2.3 ok\n");
+         Rprintf( "CQi: CQI_ASK_FEATURE_CL_2_3 ... CL v2.3 ok\n");
         cqi_data_bool(CQI_CONST_YES);
         break;
       case CQI_ASK_FEATURE_CQP_2_3:
         if (server_debug)
-          fprintf(stderr, "CQi: CQI_ASK_FEATURE_CQP_2_3 ... CQP v2.3 ok\n");
+         Rprintf( "CQi: CQI_ASK_FEATURE_CQP_2_3 ... CQP v2.3 ok\n");
         cqi_data_bool(CQI_CONST_YES);
         break;
       default:
         if (server_debug)
-          fprintf(stderr, "CQi: CQI_ASK_FEATURE_* ... <unknown feature> not supported\n");
+         Rprintf( "CQi: CQI_ASK_FEATURE_* ... <unknown feature> not supported\n");
         cqi_data_bool(CQI_CONST_NO);
       }
       break;
@@ -1619,8 +1619,8 @@ main(int argc, char *argv[])
   paging = autoshow = auto_save = 0;
 
   if (!initialize_cqp(argc, argv)) {
-    fprintf(stderr, "CQPserver: ERROR Couldn't initialise CQP engine.\n");
-    exit(1);
+   Rprintf( "CQPserver: ERROR Couldn't initialise CQP engine.\n");
+    rcqp_receive_error(1);
   }
   cqiserver_welcome();
 
@@ -1630,28 +1630,28 @@ main(int argc, char *argv[])
 
   if (0 < accept_connection(server_port)) {
     if (server_log)
-      printf("CQPserver: Connected. Waiting for CONNECT request.\n");
+     Rprintf("CQPserver: Connected. Waiting for CONNECT request.\n");
   }
   else {
-    fprintf(stderr, "CQPserver: ERROR Connection failed.\n");
-    exit(1);
+   Rprintf( "CQPserver: ERROR Connection failed.\n");
+    rcqp_receive_error(1);
   }
 
   /* establish CQi connection: wait for CONNECT request */
   cmd = cqi_read_command();
   if (cmd != CQI_CTRL_CONNECT) {
     if (server_log)
-      printf("CQPserver: Connection refused.\n");
+     Rprintf("CQPserver: Connection refused.\n");
     cqiserver_wrong_command_error(cmd);
   }
   user = cqi_read_string();
   passwd = cqi_read_string();
   if (server_log)
-    printf("CQPserver: CONNECT  user = '%s'  passwd = '%s'  pid = %d\n", user, passwd, (int)getpid());
+   Rprintf("CQPserver: CONNECT  user = '%s'  passwd = '%s'  pid = %d\n", user, passwd, (int)getpid());
 
   /* check password here (always required !!) */
   if (!authenticate_user(user, passwd)) {
-    printf("CQPserver: Wrong username or password. Connection refused.\n"); /* TODO shouldn't this be to stderr as it is not conditional on server_log? */
+   Rprintf("CQPserver: Wrong username or password. Connection refused.\n"); /* TODO shouldn't this be to stderr as it is not conditional on server_log? */
     cqi_command(CQI_ERROR_CONNECT_REFUSED);
   }
   else {
@@ -1674,11 +1674,11 @@ main(int argc, char *argv[])
     interpreter();
 
     if (server_log)
-      printf("CQPserver: User '%s' has logged off.\n", user);
+     Rprintf("CQPserver: User '%s' has logged off.\n", user);
   }
 
   /* connection terminated; clean up and exit */
-  printf("CQPserver: Exit. (pid = %d)\n", (int)getpid());
+ Rprintf("CQPserver: Exit. (pid = %d)\n", (int)getpid());
 
   /* TODO should we check cqp_error_status as in the main cqp app? */
   return 0;
